/* $Header: /cvs/gnome/gIDE/src/gI_toolbar.h,v 1.2 2000/04/14 04:34:00 jpr Exp $ */
/* gIDE
 * Copyright (C) 1998-2000 Steffen Kern
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GI_TOOLBAR_H
#define GI_TOOLBAR_H

#include <gnome.h>

/*
 * Prototypes for 'gI_toolbar.c'
 */
void gI_toolbar_create(GtkWidget* app);

#endif

